Function mycelium_util::io::empty
source · pub fn empty() -> EmptyExpand description
Constructs a new handle to an empty reader.
All reads from the returned reader will return Ok(0).
pub fn empty() -> EmptyConstructs a new handle to an empty reader.
All reads from the returned reader will return Ok(0).