Type Alias mycelium_util::io::Result
source · pub type Result<T> = Result<T, Error>;Expand description
A specialized Result type for I/O operations.
This type is broadly used across mycelium_util::io for any operation which may
produce an error.
This typedef is generally used to avoid writing out io::Error directly and
is otherwise a direct mapping to Result.
While usual Rust style is to import types directly, aliases of Result
often are not, to make it easier to distinguish between them. Result is
generally assumed to be core::result::Result, and so users of this alias
will generally use io::Result instead of shadowing the prelude’s import
of core::result::Result.
Aliased Type
enum Result<T> {
Ok(T),
Err(Error),
}